==> zzyj-financeintegration-impl-3.0.0-20220616.032307-25-sources.jar: com/ejianc/business/financeintegration/PMPayApply/bean/PMSalaryPayApplyDetailEntity.java <==
package com.ejianc.business.financeintegration.PMPayApply.bean;

import com.baomidou.mybatisplus.annotation.*;

import java.math.BigDecimal;


@TableName("PMGZFKSQSJMX")
public class PMSalaryPayApplyDetailEntity {

    private static final long serialVersionUID = 1L;

    /**
     * 主键-同支付申请表子表 id
     */
    @TableId(
            type = IdType.NONE
    )
    private String id;

    /**
     * PM单据ID（）
     */
    @TableField(value = "PMDJBH")
    private String salaryPayApplyId;


    /**
     * 姓名
     */
    @TableField(value = "NAME")
    private String workerName;


    /**
     * 性别
     */
    @TableField(value = "SEX")
    private String workerSex;

    /**
     * 账号
     */
    @TableField(value = "YHZH")
    private String workerAccountNum;

    /**
     * 金额
     */
    @TableField(value = "YFJE")
    private BigDecimal workerApplyTaxMny;//申请金额


    /**
     * 开户行
     */
    @TableField(value = "KHH")
    private String workerBankName;

    /**
     * 联行号
     */
    @TableField(value = "LHH")
    private String interBankNum;

    /**
     * 身份证
     */
    @TableField(value = "SFZBH")
    private String workerIdCard;

    /**
     * 手机号
     */
    @TableField(value = "SJH")
    private String workerPhone;

    /**
     * 状态
     * 0-待支付、1-银行支付中、2-支付成功、3-支付失败
     * PM系统新增中间表数据时，设置初始状态为“待支付”
     */
    @TableField(value = "FFZT")
    private String payState;

    /**
     * 修改时间
     */
    @TableField(
            value = "XGSJ",
            fill = FieldFill.UPDATE
    )
    private String updateTime;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSalaryPayApplyId() {
        return salaryPayApplyId;
    }

    public void setSalaryPayApplyId(String salaryPayApplyId) {
        this.salaryPayApplyId = salaryPayApplyId;
    }

    public String getWorkerName() {
        return workerName;
    }

    public void setWorkerName(String workerName) {
        this.workerName = workerName;
    }

    public String getWorkerSex() {
        return workerSex;
    }

    public void setWorkerSex(String workerSex) {
        this.workerSex = workerSex;
    }

    public String getWorkerAccountNum() {
        return workerAccountNum;
    }

    public void setWorkerAccountNum(String workerAccountNum) {
        this.workerAccountNum = workerAccountNum;
    }

    public BigDecimal getWorkerApplyTaxMny() {
        return workerApplyTaxMny;
    }

    public void setWorkerApplyTaxMny(BigDecimal workerApplyTaxMny) {
        this.workerApplyTaxMny = workerApplyTaxMny;
    }

    public String getWorkerBankName() {
        return workerBankName;
    }

    public void setWorkerBankName(String workerBankName) {
        this.workerBankName = workerBankName;
    }

    public String getInterBankNum() {
        return interBankNum;
    }

    public void setInterBankNum(String interBankNum) {
        this.interBankNum = interBankNum;
    }

    public String getWorkerIdCard() {
        return workerIdCard;
    }

    public void setWorkerIdCard(String workerIdCard) {
        this.workerIdCard = workerIdCard;
    }

    public String getWorkerPhone() {
        return workerPhone;
    }

    public void setWorkerPhone(String workerPhone) {
        this.workerPhone = workerPhone;
    }

    public String getPayState() {
        return payState;
    }

    public void setPayState(String payState) {
        this.payState = payState;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }
}

==> zzyj-financeintegration-impl-3.0.0-20250912.021450-121-sources.jar: com/ejianc/business/financeintegration/PMPayApply/bean/PMSalaryPayApplyDetailEntity.java <==
package com.ejianc.business.financeintegration.PMPayApply.bean;

import com.baomidou.mybatisplus.annotation.*;

import java.math.BigDecimal;


@TableName("PMGZFKSQSJMX")
public class PMSalaryPayApplyDetailEntity {

    private static final long serialVersionUID = 1L;

    /**
     * 主键-同支付申请表子表 id
     */
    @TableId(
            type = IdType.NONE
    )
    private String id;

    /**
     * PM单据ID（）
     */
    @TableField(value = "PMDJBH")
    private String salaryPayApplyId;


    /**
     * 姓名
     */
    @TableField(value = "NAME")
    private String workerName;


    /**
     * 性别
     */
    @TableField(value = "SEX")
    private String workerSex;

    /**
     * 账号
     */
    @TableField(value = "YHZH")
    private String workerAccountNum;

    /**
     * 金额
     */
    @TableField(value = "YFJE")
    private BigDecimal workerApplyTaxMny;//申请金额


    /**
     * 开户行
     */
    @TableField(value = "KHH")
    private String workerBankName;

    /**
     * 联行号
     */
    @TableField(value = "LHH")
    private String interBankNum;

    /**
     * 身份证
     */
    @TableField(value = "SFZBH")
    private String workerIdCard;

    /**
     * 手机号
     */
    @TableField(value = "SJH")
    private String workerPhone;

    /**
     * 状态
     * 0-待支付、1-银行支付中、2-支付成功、3-支付失败
     * PM系统新增中间表数据时，设置初始状态为“待支付”
     */
    @TableField(value = "FFZT")
    private String payState;

    /**
     * 修改时间
     */
    @TableField(
            value = "XGSJ",
            fill = FieldFill.UPDATE
    )
    private String updateTime;

    /**
     * 开户行省份
     */
    @TableField(value = "KHHSF")
    private String workerBankProvince;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSalaryPayApplyId() {
        return salaryPayApplyId;
    }

    public void setSalaryPayApplyId(String salaryPayApplyId) {
        this.salaryPayApplyId = salaryPayApplyId;
    }

    public String getWorkerName() {
        return workerName;
    }

    public void setWorkerName(String workerName) {
        this.workerName = workerName;
    }

    public String getWorkerSex() {
        return workerSex;
    }

    public void setWorkerSex(String workerSex) {
        this.workerSex = workerSex;
    }

    public String getWorkerAccountNum() {
        return workerAccountNum;
    }

    public void setWorkerAccountNum(String workerAccountNum) {
        this.workerAccountNum = workerAccountNum;
    }

    public BigDecimal getWorkerApplyTaxMny() {
        return workerApplyTaxMny;
    }

    public void setWorkerApplyTaxMny(BigDecimal workerApplyTaxMny) {
        this.workerApplyTaxMny = workerApplyTaxMny;
    }

    public String getWorkerBankName() {
        return workerBankName;
    }

    public void setWorkerBankName(String workerBankName) {
        this.workerBankName = workerBankName;
    }

    public String getInterBankNum() {
        return interBankNum;
    }

    public void setInterBankNum(String interBankNum) {
        this.interBankNum = interBankNum;
    }

    public String getWorkerIdCard() {
        return workerIdCard;
    }

    public void setWorkerIdCard(String workerIdCard) {
        this.workerIdCard = workerIdCard;
    }

    public String getWorkerPhone() {
        return workerPhone;
    }

    public void setWorkerPhone(String workerPhone) {
        this.workerPhone = workerPhone;
    }

    public String getPayState() {
        return payState;
    }

    public void setPayState(String payState) {
        this.payState = payState;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getWorkerBankProvince() {
        return workerBankProvince;
    }

    public void setWorkerBankProvince(String workerBankProvince) {
        this.workerBankProvince = workerBankProvince;
    }
}
